@@ -46,6 +46,12 @@ def create_credential_resolver(session, cache=None, region_name=None):
     num_attempts = session.get_config_variable('metadata_service_num_attempts')
     disable_env_vars = session.instance_variables().get('profile') is not None
 
+    imds_config = {
+        'ec2_metadata_service_endpoint': session.get_config_variable(
+            'ec2_metadata_service_endpoint'),
+        'imds_use_ipv6': session.get_config_variable('imds_use_ipv6')
+    }
+
     if cache is None:
         cache = {}
 
@@ -55,7 +61,8 @@ def create_credential_resolver(session, cache=None, region_name=None):
         iam_role_fetcher=AioInstanceMetadataFetcher(
             timeout=metadata_timeout,
             num_attempts=num_attempts,
-            user_agent=session.user_agent())
+            user_agent=session.user_agent(),
+            config=imds_config)
     )
 
     profile_provider_builder = AioProfileProviderBuilder(
@@ -817,6 +824,8 @@ class AioCredentialResolver(CredentialResolver):
 
 
 class AioSSOCredentialFetcher(AioCachedCredentialFetcher):
+    _UTC_DATE_FORMAT = '%Y-%m-%dT%H:%M:%SZ'
+
     def __init__(self, start_url, sso_region, role_name, account_id,
                  client_creator, token_loader=None, cache=None,
                  expiry_window_seconds=None):
@@ -826,7 +835,6 @@ class AioSSOCredentialFetcher(AioCachedCredentialFetcher):
         self._account_id = account_id
         self._start_url = start_url
         self._token_loader = token_loader
-
         super(AioSSOCredentialFetcher, self).__init__(
             cache, expiry_window_seconds
         )
@@ -846,7 +854,7 @@ class AioSSOCredentialFetcher(AioCachedCredentialFetcher):
         # fromtimestamp expects seconds so: milliseconds / 1000 = seconds
         timestamp_seconds = timestamp_ms / 1000.0
         timestamp = datetime.datetime.fromtimestamp(timestamp_seconds, tzutc())
-        return _serialize_if_needed(timestamp)
+        return timestamp.strftime(self._UTC_DATE_FORMAT)
 
     async def _get_credentials(self):
         """Get credentials by calling SSO get role credentials."""
